function [Spectr,iFund]=oscspectr(OscRecord,iChannel,fFund=0)
  
# [Spectr, iFund] = oscspectr(OscRecord, iChannel, fFund)
#
# Uses spectr() to calculate the frequency spectrum of an oscilloscope waveform 
# contained in the OscRecord structure and returns a corresponding Spectr 
# structure. The waveform is identified by iChannel which is its numerical index 
# in OscRecord.
#
# The component number in Spectr corresponding to the fundamental frequency 
# fFund is returned in iFund. If fFund is not given, then iFund = 2 (which 
# corresponds to the first alternating component).
#
# For a description of the Spectr structure, see spectr().

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology
  
  [t,y] = oscgetxy(OscRecord, iChannel);
  Spectr = spectr(y, t, fFund);
  if (fFund > 0)
    iFund = findnearest(Spectr.f, fFund);
  else
    iFund = 2;
  endif
  
endfunction
